## gopup (python3)

#### 建议安装方法
    pip install gopup

#### 升级方法
    pip install gopup --upgrade

GoPUP 支持Python 3.7+，旨在使获取数据尽可能方便，主要用于学术研究目的。

GoPUP 项目所采集的数据皆来自公开的数据源，不涉及任何个人隐私数据和非公开数据。 同时本项目提供的数据接口及相关数据仅用于学术研究，任何个人、机构及团体使用本项目的数据接口及相关数据请注意商业风险。

文档：[中文文档](https://gopup-cookbook.readthedocs.io) 

####  数据仓库

- 指数数据
    - 微博指数数据
    - 百度搜索数据
    - 百度资讯指数
    - 百度媒体指数
- 宏观数据
    - 中国宏观数据
        - 中国宏观杠杆率数据
        - 年度国内生产总值数据
        - 季度国内生产总值数据
        - 三大需求对GDP贡献数据
        - 三大产业对GDP拉动数据
        - 三大产业贡献率数据
        - 居民消费价格指数
        - 工业品出厂价格指数
        - 存款利率数据
        - 贷款利率数据
        - 存款准备金率数据
        - 货币供应量数据
        - 货币供应量(年底余额)数据
        - 外汇储备
    - 利率数据
        - Shibor数据
        - Shibor报价数据
        - Shibor均值数据
        - LPR数据
- 新经济公司
    - 千里马公司
    - 独角兽公司
    - 倒闭公司
    - 商业特许经营公司
- 生活数据
    - 影视数据
        - 实时电影票房数据
        - 单日电影票房数据
        - 单日影院票房数据
        - 实时电视剧播映指数
        - 实时综艺播映指数
        - 艺人商业价值
        - 艺人流量价值
- 疫情数据
    - 网易疫情数据
    - 丁香园疫情数据
    - 疫情历史数据
    - 百度疫情数据
    - 百度迁徙数据
    
    
#### 版本更新
    
    0.1.9
    影视数据：电影票房数据、影院票房、电视剧播映指数、综艺播映指数、艺人商业价值、艺人流量价值
    
    0.1.8
    新经济公司：千里马公司、独角兽公司、倒闭公司、商业特许经营公司
    
    0.1.4
    利率数据：Shibor数据、Shibor报价数据、Shibor均值数据、LPR数据
    
    0.1.1
    宏观经济：中国宏观经济
    
    0.1.0 
    规范说明文档格式
    指数数据：微博指数、百度指数
    疫情数据：网易疫情数据、丁香园疫情数据、百度疫情数据、百度迁徙数据、疫情历史数据  